%define osmo		Osmo4

# disable format string check, can't fix it for WxWidgets part
%define Werror_cflags	%{nil}

# looks like no stable ABI => version is %%major
%define major		7
%define libname		%mklibname %{name} %{major}
%define modname		%mklibname %{name}-modules
%define devname		%mklibname %{name} -d

Name: 	 	gpac
Version: 	0.7.1
Release: 	%mkrel 6
Summary: 	MPEG-4 multimedia framework
License:	LGPLv2+
Group:		Video/Utilities
URL:		http://gpac.wp.mines-telecom.fr/
Source:		https://github.com/gpac/gpac/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		110_all_implicitdecls.patch
Patch1:		210_all_system_libogg.patch
Patch2:		gpac-0.6.1-openssl11.patch
Patch3:		gpac-0.7.1-ffmpeg-4.0.patch
Patch4:		CVE-2018-7752-CVE-2018-1000100.patch
Patch5:		CVE-2018-13005-CVE-2018-13006.patch
Patch6:		CVE-2018-20760.patch
Patch7:		CVE-2018-20761-CVE-2018-20762.patch
Patch8:		CVE-2018-20763.patch

BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(libopenjpeg1)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(xv)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	a52dec-devel
BuildRequires:	ImageMagick
BuildRequires:	ffmpeg-devel
BuildRequires:	freeglut-devel
BuildRequires:	jpeg-devel
BuildRequires:	libfaad2-devel
BuildRequires:	xvid-devel
BuildRequires:	wxgtku3.0-devel
BuildRequires:	subversion

%description
GPAC is a multimedia framework based on the MPEG-4 Systems standard developed
from scratch in ANSI C.  The original development goal is to provide a clean
(a.k.a. readable by as many people as possible), small and flexible
alternative to the MPEG-4 Systems reference software.

The natural evolution has been the integration of recent multimedia standards
(SVG/SMIL, VRML, X3D, SWF, 3GPP(2) tools, etc) into a single framework.
VRML97 and a good amount of the X3D standard have already been integrated
into GPAC, as well as some SVG support and experimental Macromedia Flash
support.

The current GPAC release (%{version}) already covers a very large part of the
MPEG-4 standard, and has some good support for 3GPP and VRML/X3D, and
features what can probably be seen as the most advanced and robust 2D MPEG-4
Player available worldwide, as well as a decent 3D player.

GPAC also features MPEG-4 Systems encoders/multiplexers, publishing tools for
content distribution for MP4 and 3GPP(2) files and many tools for scene
descriptions (MPEG4<->VRML<->X3D converters, SWF->MPEG-4, etc...).

This package is in tainted repository because it incorporates MPEG-4 technology,
covered by software patents.

%package -n	%{libname}
Summary:	GPAC shared library
Group:		System/Libraries

%description -n	%{libname}
GPAC is a multimedia framework based on the MPEG-4 Systems standard developed
from scratch in ANSI C.

This package provides the GPAC shared library.

This package is in tainted repository because it incorporates MPEG-4
technology which may be covered by software patents.

%package -n	%{devname}
Summary:	Development headers and library for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
Development headers and libraries for %{name}.

This package is in tainted repository because it incorporates MPEG-4
technology which may be covered by software patents.

%prep
%setup -q
%autopatch -p1

# SHH!
sed -i -e 's/Wall/w/g' `find -name Makefile`

# remove last of internal ogg
sed -i -e 's:<gpac/internal/ogg.h>:<ogg/ogg.h>:' \
	src/media_tools/{av_parsers,gpac_ogg,media_import,media_export}.c
rm -f include/gpac/internal/ogg.h

%build
%configure2_5x \
		--libdir=%{_lib} \
		--use-js=no \
		--use-ffmpeg=system \
		--use-ogg=system \
		--extra-cflags="%{optflags}" \
		--enable-pic

%make_build

%install
# Makefile needs the pkgconfig dir to install the gpac.pc file otherwise it can't
mkdir -p %{buildroot}%{_libdir}/pkgconfig

%make_install install-lib

%if 0
# menu
mkdir -p %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{_real_vendor}-%{osmo}.desktop
[Desktop Entry]
Name=%{osmo}
Comment=MPEG-4 Media Player
Exec=%{osmo}
Icon=%{osmo}
Terminal=false
Type=Application
Categories=AudioVideo;Video;
EOF

#icons
mkdir -p %{buildroot}%{_liconsdir}
convert -size 48x48 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_liconsdir}/%{osmo}.png
mkdir -p %{buildroot}%{_iconsdir}
convert -size 32x32 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_iconsdir}/%{osmo}.png
mkdir -p %{buildroot}%{_miconsdir}
convert -size 16x16 applications/osmo4_wx/osmo4.xpm %{buildroot}%{_miconsdir}/%{osmo}.png
%endif

%files
%doc AUTHORS BUGS Changelog COPYING README.md TODO
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man1/*.1.*

%files -n %{libname}
%{_libdir}/libgpac.so.%{major}
%{_libdir}/libgpac.so.%{major}.*

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libgpac.so
%{_libdir}/libgpac_static.a


%changelog
* Mon Apr 01 2019 daviddavid <daviddavid> 0.7.1-6.mga7
+ Revision: 1384163
- add upstream patches to fix CVE-2018-7752, CVE-2018-1300[56],
  CVE-2018-2076[0-3], CVE-2018-1000100 (mga#24601)

* Thu Sep 20 2018 umeabot <umeabot> 0.7.1-5.mga7.tainted
+ Revision: 1278634
- Mageia 7 Mass Rebuild

* Sun Sep 09 2018 wally <wally> 0.7.1-4.mga7.tainted
+ Revision: 1257952
- rebuild for aarch64

* Mon Apr 23 2018 daviddavid <daviddavid> 0.7.1-3.mga7.tainted
+ Revision: 1221795
- add upstream patch to fix build with ffmpeg >= 4.0
+ zezinho <zezinho>
- rebuild against ffmpeg 4
+ kekepower <kekepower>
- Rebuild for new openjpeg

* Sun Jan 07 2018 daviddavid <daviddavid> 0.7.1-1.mga7.tainted
+ Revision: 1191284
- new version: 0.7.1
- remove no more needed link patch

* Sat Sep 09 2017 cjw <cjw> 0.6.1-5.mga7.tainted
+ Revision: 1152092
- fix build with openssl 1.1

* Wed Mar 08 2017 akien <akien> 0.6.1-4.mga6.tainted
+ Revision: 1090270
- Rebuild for ffmpeg 3.2.4

* Sat Oct 15 2016 pterjan <pterjan> 0.6.1-3.mga6.tainted
+ Revision: 1060996
- Enable pic

* Sun Aug 21 2016 daviddavid <daviddavid> 0.6.1-2.mga6.tainted
+ Revision: 1047620
- rebuild (should be without directfb now)

* Tue Mar 22 2016 daviddavid <daviddavid> 0.6.1-1.mga6.tainted
+ Revision: 994056
- new version: 0.6.1
- now libmajor is 6
- rediff 210_all_system_libogg patch

* Sun Mar 20 2016 wally <wally> 0.5.2-3.mga6.tainted
+ Revision: 993068
- rebuild for arm

* Sat Jan 02 2016 luigiwalser <luigiwalser> 0.5.2-2.mga6.tainted
+ Revision: 918287
- rebuild without directfb

* Tue Jun 23 2015 daviddavid <daviddavid> 0.5.2-1.mga6.tainted
+ Revision: 841108
- new version: 0.5.2
- now major is 4
- switch Source0 Url on new upstream Github
- remove all no more needed Patches (as merged upstream)
- rename and rediff gpac-link.patch
- add more BuildRequires on libopenjpeg1 and a52dec
- now 'install-lib' option installs automatically the static library
- add pkgconfig file on gpac.pc

* Sat Nov 15 2014 cjw <cjw> 0.5.0-8.mga5.tainted
+ Revision: 797303
- patch8: fix build with ffmpeg 2.4
- add static library for x264

* Wed Oct 15 2014 umeabot <umeabot> 0.5.0-7.mga5.tainted
+ Revision: 743041
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.5.0-6.mga5.tainted
+ Revision: 679903
- Mageia 5 Mass Rebuild

* Sat Aug 09 2014 tv <tv> 0.5.0-5.mga5.tainted
+ Revision: 661252
- bump release

* Sun Jul 13 2014 daviddavid <daviddavid> 0.5.0-4.mga5.tainted
+ Revision: 651743
- rebuild for new libdirectfb
- use correct macro on %%configure2_5x and %%makeinstall_std
- switch to pkgconfig on BRs
- update URL and link URL for Source

* Thu Oct 31 2013 tmb <tmb> 0.5.0-3.mga4.tainted
+ Revision: 548187
- Mageia 4 rebuild

* Sat Aug 17 2013 fwang <fwang> 0.5.0-2.mga4.tainted
+ Revision: 467283
- rebuild for new dfb

* Fri Aug 16 2013 fwang <fwang> 0.5.0-1.mga4.tainted
+ Revision: 466793
- enable dfb link patch
- sync with gentoo patches
- fix include path
- fix build with recent ffmpeg 2.0
- rebuild for new openjpeg

* Sat Jan 12 2013 umeabot <umeabot> 0.4.5-15.mga3.tainted
+ Revision: 352485
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 fwang <fwang> 0.4.5-14.mga3.tainted
+ Revision: 303277
- update rpm group
- rebuild for new openjpeg

* Sat Jul 28 2012 fwang <fwang> 0.4.5-13.mga3.tainted
+ Revision: 275262
- rebuild for new dfb

* Fri Apr 13 2012 fwang <fwang> 0.4.5-12.mga2.tainted
+ Revision: 230589
- really drop old packages

* Fri Apr 13 2012 fwang <fwang> 0.4.5-11.mga2.tainted
+ Revision: 230585
- drop old packages

* Fri Apr 13 2012 fwang <fwang> 0.4.5-10.mga2.tainted
+ Revision: 230581
- drop osmo package, as upstream disabled it by default
- update file list
- fix typo
- use libidr opt
- br svnversion
- update relative patch
- more ffmpeg patch
- more patch
- more fix
- more ffmpeg fix
- correct use ldflags
- use system ffmpeg

* Thu Apr 12 2012 fwang <fwang> 0.4.5-9.mga2.tainted
+ Revision: 230434
- drop correct dir
- do not use bundled ffmpeg header
- fix build
- use swscale
- use ldflags
- more linkage fix
- add more link patch
- using newer symbols

* Thu Apr 12 2012 fwang <fwang> 0.4.5-8.mga2.tainted
+ Revision: 230371
- rebuild for new openjpeg

* Thu Jan 19 2012 fwang <fwang> 0.4.5-7.mga2.tainted
+ Revision: 198443
- do not promote openjpeg version for now
- do not promote openjpeg version for now
- more linkage fix
- more linkage fix
- more linkage fix
- fix linkage
- drop invalid linker option
- build gtku version

* Tue Sep 20 2011 fwang <fwang> 0.4.5-6.mga2.tainted
+ Revision: 146100
- fix build with latest libpng 1.5
- rebuild for new libpng

* Tue Aug 30 2011 fwang <fwang> 0.4.5-5.mga2.tainted
+ Revision: 136307
- br freeglut

* Sat Jun 25 2011 fwang <fwang> 0.4.5-4.mga2.tainted
+ Revision: 113829
- main pkg do not need to contain shared lib and its symlink

* Sat Jun 25 2011 fwang <fwang> 0.4.5-3.mga2.tainted
+ Revision: 113579
- rebuild for new ffmpeg

* Sun May 08 2011 anssi <anssi> 0.4.5-2.mga1
+ Revision: 96550
- fix library packaging according to policy
- fix license tag
+ mikala <mikala>
- Add a xdg menu for Osmo4 player
- use %%buildroot
- Remove plf reference
- clean spec
- imported package gpac


* Sat Apr 11 2009 Anssi Hannula <anssi@zarb.org> 0.4.5-1plf2009.1
- new version (from bug #174)
- add more buildrequires

* Mon Apr 14 2008 Anssi Hannula <anssi@zarb.org> 0.4.4-0.rc2.1plf2008.1
- new version

* Sat Oct 21 2006 Anssi Hannula <anssi@zarb.org> 0.4.3-0.20061021.1plf2007.0
- new snapshot
- fix buildrequires for backportability
- buildrequire wxGTK2.6-devel explicitely, build with 2.7 fails
- standardize PLF reason

* Fri Sep 01 2006 Anssi Hannula <anssi@zarb.org> 0.4.1-0.20060630.2plf2007.0
- lib64 fixes

* Fri Jan 30 2006 Austin Acton <austin@mandriva.org> 0.4.1-0.20060630.1plf2007.0
- initial package
